@@ -11,6 +11,7 @@ ONEDRIVE_PATH = "covid-onedrive:'COVID-19 Resource Hub'"
 NOAA_PM_DATA = "ftp://ftp.cdc.noaa.gov/Datasets/ncep.reanalysis.dailyavgs/surface_gauss/air.2m.gauss.2020.nc"
 CITYMAPPER_MOBILITY_TEMPLATE = "https://cdn.citymapper.com/data/cmi/Citymapper_Mobility_Index_{DATE}.csv"
 OPEN_COVID19_GROUP_REPO = "https://github.com/beoutbreakprepared/nCoV2019/archive/master.zip"
+CDC_DEATHS_BY_RACE_ETHNICITY_AGE_STATE = "https://data.cdc.gov/api/views/ks3g-spdg/rows.csv?accessType=DOWNLOAD"
 
 # Shared paths
 EXEC_R_SCRIPT_PATH = Path('/share/singularity-images/lbd/shells/singR.sh')
@@ -42,6 +43,7 @@ SEIR_COVARIATES_OUTPUT_ROOT = Path('/ihme/covid-19/seir-covariates')
 SEIR_FIT_OUTPUTS = Path('/ihme/covid-19/seir-fit')
 SEIR_REGRESSION_OUTPUTS = Path('/ihme/covid-19/seir-regression')
 SEIR_FORECAST_OUTPUTS = Path('/ihme/covid-19/seir-forecast')
+SEIR_FINAL_OUTPUTS = Path('/ihme/covid-19/seir-outputs')
 
 
 # Shared file names
@@ -54,6 +56,7 @@ JOHNS_HOPKINS_OUTPUT_DIR_NAME = Path('johns_hopkins_repo')
 ITALY_OUTPUT_DIR_NAME = Path('italy_repo')
 NY_TIMES_OUTPUT_DIR_NAME = Path('ny_times_repo')
 NOAA_OUTPUT_DIR_NAME = Path('noaa_data')
+CDC_OUTPUT_DIR_NAME = Path('cdc_data')
 MOBILITY_OUTPUT_DIR_NAME = Path('mobility_data')
 ONEDRIVE_OUTPUT_DIR_NAME = Path('covid_onedrive')
 OPEN_COVID19_OUTPUT_DIR_NAME = Path('open_covid19_working_group')
